@@ -1,45 +1,38 @@
 package Net::CLI::Interact::ActionSet;
 {
-  $Net::CLI::Interact::ActionSet::VERSION = '1.121640';
+  $Net::CLI::Interact::ActionSet::VERSION = '2.133420';
 }
 
-use Moose;
+use Moo;
+use Sub::Quote;
+use MooX::Types::MooseLike::Base qw(InstanceOf ArrayRef CodeRef RegexpRef);
 use Net::CLI::Interact::Action;
-with 'Net::CLI::Interact::Role::Iterator';
 
-use Moose::Util::TypeConstraints;
-subtype 'Net::CLI::Interact::ActionSet::CurrentMatchType'
-    => as 'Maybe[ArrayRef[RegexpRef]]';
-coerce 'Net::CLI::Interact::ActionSet::CurrentMatchType'
-    => from 'RegexpRef' => via { [$_] };
+with 'Net::CLI::Interact::Role::Iterator';
 
 has default_continuation => (
     is => 'rw',
-    isa => 'Maybe[Net::CLI::Interact::ActionSet]',
-    required => 0,
+    isa => InstanceOf['Net::CLI::Interact::ActionSet'],
+    predicate => 1,
 );
 
 has current_match => (
     is => 'rw',
-    isa => 'Net::CLI::Interact::ActionSet::CurrentMatchType',
-    required => 0,
-    coerce => 1,
-);
-
-has '+_sequence' => (
-    isa => 'ArrayRef[Net::CLI::Interact::Action]',
+    isa => ArrayRef[RegexpRef],
+    predicate => 1,
+    coerce => quote_sub(q{ (ref qr// eq ref $_[0]) ? [$_[0]] : $_[0] }),
 );
 
 sub BUILDARGS {
     my ($class, @rest) = @_;
 
     # accept single hash ref or naked hash
-    my $params = (ref $rest[0] eq ref {} and scalar @rest == 1 ? $rest[0] : {@rest});
+    my $params = (ref {} eq ref $rest[0] ? $rest[0] : {@rest});
 
     if (exists $params->{actions} and ref $params->{actions} eq ref []) {
         foreach my $a (@{$params->{actions}}) {
             if (ref $a eq 'Net::CLI::Interact::ActionSet') {
-                push @{$params->{_sequence}}, $a->_sequence;
+                push @{$params->{_sequence}}, @{ $a->_sequence };
                 next;
             }
 
@@ -54,7 +47,7 @@ sub BUILDARGS {
                 next;
             }
 
-            confess "don't know what to do with a: '$a'\n";
+            die "don't know what to do with a: '$a'\n";
         }
         delete $params->{actions};
     }
@@ -65,10 +58,10 @@ sub BUILDARGS {
 sub clone {
     my $self = shift;
     return Net::CLI::Interact::ActionSet->new({
-        actions => [ map { $_->clone } $self->_sequence ],
-        _callbacks => $self->_callbacks,
-        default_continuation => $self->default_continuation,
-        current_match => $self->current_match,
+        actions => [ map { $_->clone } @{ $self->_sequence } ],
+        ($self->_has_callbacks ? (_callbacks => $self->_callbacks) : ()),
+        ($self->has_default_continuation ? (default_continuation => $self->default_continuation) : ()),
+        ($self->has_current_match ? (current_match => $self->current_match) : ()),
     });
 }
 
@@ -85,9 +78,9 @@ sub apply_params {
 
 has _callbacks => (
     is => 'rw',
-    isa => 'ArrayRef[CodeRef]',
-    required => 0,
+    isa => ArrayRef[CodeRef],
     default => sub { [] },
+    predicate => 1,
 );
 
 sub register_callback {
@@ -164,8 +157,8 @@ sub _marshall_responses {
         next unless $match->type eq 'match';
 
         # remove echoed command from the beginning
-        my $cmd = quotemeta( $send->value );
-        (my $output = $match->response_stash) =~ s/^$cmd\s*//;
+        my $cmd = quotemeta( sprintf $send->value, @{ $send->params } );
+        (my $output = $match->response_stash) =~ s/^${cmd}[\t ]*(?:\r\n|\r|\n)?//s;
         $send->response($output);
     }
 }
@@ -184,7 +177,7 @@ Net::CLI::Interact::ActionSet - Conversation of Send and Match Actions
 
 =head1 VERSION
 
-version 1.121640
+version 2.133420
 
 =head1 DESCRIPTION
 
@@ -300,7 +293,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2013 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
